@@ -1,6 +1,7 @@
 import json
 import logging
 import re
+from datetime import datetime
 from typing import AsyncIterator, List
 
 import httpx
@@ -39,10 +40,11 @@ class WicaStream(object):
         self,
         channels: List[str] | List[WicaChannel],
         stream_properties: WicaStreamProperties | None = None,
-        base_url: str = "127.0.0.1/ca/streams",
+        base_url: str = "http://127.0.0.1",
+        endpoint: str = "/ca/streams",
     ) -> None:
         self.id: int = None
-        self.base_url = base_url
+        self.url = base_url + endpoint
         self.channels = [
             WicaChannel(name=channel) if isinstance(channel, str) else channel
             for channel in channels
@@ -50,14 +52,16 @@ class WicaStream(object):
         self.stream_properties = stream_properties
         self._logger = logging.getLogger(self.__class__.__module__)
         self._logger.debug(
-            f"Initialized AsyncWicaStream for channels {channels} with base_url {base_url}"
+            f"Initialized AsyncWicaStream for channels {channels} with url {self.url}"
         )
 
     async def __aenter__(self):
         self.id = await self.create()
         return self
 
-    async def __aexit__(self, _channel, _properties, _url):
+    async def __aexit__(
+        self, _channel=None, _properties=None, _base_url=None, _endpoint=None
+    ):
         _ = await self.destroy()
         self.id = None
         return self
@@ -72,7 +76,7 @@ class WicaStream(object):
 
         ```python
         >>> for _ in range(10):
-        >>>     wica_stream = AsyncWicaStream(base_url="http://student08/ca/streams", channels=["MMAC3:STR:2"])
+        >>>     wica_stream = AsyncWicaStream(base_url="http://example.ch", endpoint="/ca/streams" channels=["MMAC3:STR:2"])
         >>>     streams.append(wica_stream)
         >>>     await wica_stream.create()
         >>>
@@ -86,7 +90,7 @@ class WicaStream(object):
         >>>     subscribed_streams.append(wica_stream.subscribe())
         ```
 
-        See examples for more detail!
+        See examples in the README for more detail!
 
 
         Retruns:
@@ -109,7 +113,7 @@ class WicaStream(object):
             payload = {"channels": channels_payload}
         async with httpx.AsyncClient() as client:
             try:
-                response = await client.post(url=self.base_url, json=payload)
+                response = await client.post(url=self.url, json=payload)
                 if response.is_success:
                     self.id = int(response.json())
                     self._logger.debug(
@@ -124,14 +128,14 @@ class WicaStream(object):
                     f"A RequestError occurred while creating stream {exc.request.url!r}."
                 )
                 raise StreamNotCreatedException(
-                    "A RequestError occurred while creating stream {exc.request.url!r}."
+                    f"A RequestError occurred while creating stream {exc.request.url!r}."
                 )
             except httpx.HTTPStatusError as exc:
                 self._logger.debug(
                     f"StatusError response {exc.response.status_code} while creating stream {exc.request.url!r}."
                 )
                 raise StreamNotCreatedException(
-                    "StatusError response while creating stream {exc.request.url!r}."
+                    f"StatusError response while creating stream {exc.request.url!r}."
                 )
 
     async def subscribe(self) -> AsyncIterator[WicaMessage]:
@@ -159,7 +163,7 @@ class WicaStream(object):
             try:
                 # get the stream
                 async with client.stream(
-                    "GET", url=self.base_url + f"/{self.id}"
+                    "GET", url=self.url + f"/{self.id}"
                 ) as response:
                     if response.is_success:
                         wica_client = WicaSSEClient(response.aiter_bytes())
@@ -175,8 +179,9 @@ class WicaStream(object):
                                 if message.event == "heartbeat"
                                 else json.loads(event.data)
                             )
-                            message.time = re.search(regex_time, event.msg_info).group(
-                                0
+                            _time = re.search(regex_time, event.msg_info).group(0)
+                            message.time = (
+                                datetime.fromisoformat(_time) if _time else None
                             )
                             yield message
                     else:
@@ -218,7 +223,7 @@ class WicaStream(object):
                     raise StreamNotDeletedException(
                         "Stream was not deleted because no ID was provided!"
                     )
-                response = await client.delete(url=self.base_url + f"/{self.id}")
+                response = await client.delete(url=self.url + f"/{self.id}")
                 if response.is_success:
                     return response
                 else:
